@@ -1,5 +1,6 @@
 from floraconcierge.client.types import Object
 from floraconcierge.mapping.mixins.model.shop import Currency as CurrencyMixin
+from floraconcierge.mapping.mixins.model.shop import Product as ProductMixin
 
 
 class Order(Object):
@@ -123,7 +124,7 @@ class Salon(Object):
         super(Salon, self).__init__(*args, **kwargs)
 
 
-class Product(Object):
+class Product(ProductMixin):
 
     """
     :type categories: list|Collection
