@@ -45,7 +45,7 @@ class FloraConciergeRequests(Panel):
             }
 
             try:
-                q['width_ratio'] = (q['duration'] / self._calls_time) * 100
+                q['width_ratio'] = (q['duration_ms'] / self._calls_time) * 100
                 q['width_ratio_relative'] = (100.0 * q['width_ratio'] / (100.0 - width_ratio_tally))
             except ZeroDivisionError:
                 q['width_ratio'] = 0
