@@ -148,6 +148,12 @@ class Shop(Service):
         """
         return self._callapi("shop/product", get={"id": id})
 
+    def get_products_of_day(self):
+        """
+        :rtype : list of Product|Collection
+        """
+        return self._callapi("shop/products/day")
+
     def get_featured_products(
             self,
             city_id=None,
